| rflexBART | R Documentation |
Draws several binary regression trees from the flexBART tree prior, resulting in a single prior draw from the sum-of-trees prior.
rflexBART(train_data,nd,verbose = TRUE,
print_every = floor(nd/10),...)
train_data |
an object of class |
nd |
Number of trees to draw |
verbose |
Logical, indicating whether a message should be printed to the R console after every |
print_every |
If |
... |
Additional arguments for setting prior hyperparameters (e.g., number of trees, |
This function is useful for drawing samples from the regression tree prior underpinning flexBART. Together, these sampled trees form a single ensemble of trees. The main utility of this function is to study how often certain observations are clustered together in individual trees. This is key to understanding how flexBART “borrows strength” across observations.
A list containing
num_leafs |
An integer vector of length |
num_singletons |
An integer vector of length |
num_empty |
An integer vector of length |
max_leaf_size |
An integer vector of length |
min_leaf_size |
An integer vector of length |
kernel |
An |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.